@@ -22,7 +22,7 @@ def compute_target_lengths(targets):
 
 
 def select_contains_alias_call(expression):
-    if not hasattr(expression.value.func, "attrname"):
+    if not hasattr (expression.value, "func") or not hasattr(expression.value.func, "attrname"):
         return False
     if expression.value.func.attrname == "select":
         for arg in expression.value.args:
@@ -134,12 +134,33 @@ def get_length(arg):
         base_length = 2 # brackets
         total_length = base_length + get_length(arg.value) + get_length(arg.slice)
         return total_length
-    if isinstance(arg, astroid.nodes.JoinedStr):
+    if isinstance(arg, astroid.nodes.JoinedStr) or isinstance(arg, astroid.nodes.FormattedValue):
         base_length = 3 # quotes and 'f'
         total_length = 0
         for value in arg.values:
             total_length += get_length(value)
         total_length += base_length
         return total_length
+    if isinstance(arg, astroid.nodes.Starred):
+        base_length = 1 # '*'
+        total_length = 0
+        for value in arg.values:
+            total_length += get_length(value)
+        total_length += base_length
+        return total_length
+    if isinstance(arg, astroid.nodes.Slice):
+        base_length = 3 # brackets and ':'
+        total_length = 0
+        for value in arg.values:
+            total_length += get_length(value)
+        total_length += base_length
+        return total_length
+    if isinstance(arg, astroid.nodes.UnaryOp):
+        base_length = 1 # operator
+        total_length = 0
+        for value in arg.values:
+            total_length += get_length(value)
+        total_length += base_length
+        return total_length
     print(f"Unhandled {arg}")
     return 0
