@@ -10,19 +10,19 @@ import astroid
 from pylint.checkers import BaseChecker
 from pylint.interfaces import IAstroidChecker
 
-from pylint_utils import select_contains_alias_call
+from .pylint_utils import select_contains_alias_call
 
 
 class SelectCastChecker(BaseChecker):
     __implements__ = IAstroidChecker
 
-    name = 'select-cast'
+    name = "select-cast"
     priority = -1
     msgs = {
-        'E1076': (
-            'Select statements should not contain .cast calls',
-            'select-contains-cast',
-            'Readability of select calls can be much improved by extracting .cast calls.'
+        "E1076": (
+            "Select statements should not contain .cast calls",
+            "select-contains-cast",
+            "Readability of select calls can be much improved by extracting .cast calls.",
         ),
     }
 
@@ -42,7 +42,7 @@ class SelectCastChecker(BaseChecker):
 
     def visit_expr(self, node):
         if select_contains_alias_call(node):
-            self.add_message('select-contains-cast', node=node)
+            self.add_message("select-contains-cast", node=node)
 
     def leave_functiondef(self, node):
         self._function_stack.pop()
